|
From: <ba...@us...> - 2008-09-15 21:31:49
|
Revision: 976
http://omc.svn.sourceforge.net/omc/?rev=976&view=rev
Author: bartw
Date: 2008-09-15 21:31:55 +0000 (Mon, 15 Sep 2008)
Log Message:
-----------
OMC_UnitaryComputerSystem -> OMC_ComputerSystem
Modified Paths:
--------------
pybase/trunk/OMC_Base.mof
pybase/trunk/OMC_ComputerSystem-peg.reg
pybase/trunk/OMC_ComputerSystem.mof
pybase/trunk/OMC_ComputerSystem.py
pybase/trunk/OMC_InitdService.mof
pybase/trunk/OMC_InitdService.py
pybase/trunk/OMC_LogicalFile.py
pybase/trunk/OMC_OperatingSystem.mof
pybase/trunk/OMC_OperatingSystem.py
pybase/trunk/OMC_SyslogNG.py
pybase/trunk/OMC_TimeService.mof
pybase/trunk/OMC_TimeService.py
pybase/trunk/OMC_UnixProcess.py
pybase/trunk/setup.py
Modified: pybase/trunk/OMC_Base.mof
===================================================================
--- pybase/trunk/OMC_Base.mof 2008-09-15 21:30:47 UTC (rev 975)
+++ pybase/trunk/OMC_Base.mof 2008-09-15 21:31:55 UTC (rev 976)
@@ -1,4 +1,4 @@
-#pragma include ("OMC_UnitaryComputerSystem.mof")
+#pragma include ("OMC_ComputerSystem.mof")
#pragma include ("OMC_OperatingSystem.mof")
#pragma include ("OMC_LogicalFile.mof")
#pragma include ("OMC_UnixProcess.mof")
Modified: pybase/trunk/OMC_ComputerSystem-peg.reg
===================================================================
--- pybase/trunk/OMC_ComputerSystem-peg.reg 2008-09-15 21:30:47 UTC (rev 975)
+++ pybase/trunk/OMC_ComputerSystem-peg.reg 2008-09-15 21:31:55 UTC (rev 976)
@@ -1,10 +1,10 @@
-//////// OMC_UnitaryComputerSystem
+//////// OMC_ComputerSystem
instance of PG_ProviderModule
{
- Name = "/usr/lib/pycim/OMC_UnitaryComputerSystem.py";
+ Name = "/usr/lib/pycim/OMC_ComputerSystem.py";
InterfaceType = "Python";
InterfaceVersion = "1.0.0";
- Location = "/usr/lib/pycim/OMC_UnitaryComputerSystem.py";
+ Location = "/usr/lib/pycim/OMC_ComputerSystem.py";
UserContext = 2; // Requestor
Vendor = "OMC";
Version = "0.1.0";
@@ -12,16 +12,16 @@
instance of PG_Provider
{
- Name = "OMC_UnitaryComputerSystem";
- ProviderModuleName = "/usr/lib/pycim/OMC_UnitaryComputerSystem.py";
+ Name = "OMC_ComputerSystem";
+ ProviderModuleName = "/usr/lib/pycim/OMC_ComputerSystem.py";
};
instance of PG_ProviderCapabilities
{
- CapabilityID = "OMC_UnitaryComputerSystem";
- ProviderModuleName = "/usr/lib/pycim/OMC_UnitaryComputerSystem.py";
- ProviderName = "OMC_UnitaryComputerSystem";
- ClassName = "OMC_UnitaryComputerSystem";
+ CapabilityID = "OMC_ComputerSystem";
+ ProviderModuleName = "/usr/lib/pycim/OMC_ComputerSystem.py";
+ ProviderName = "OMC_ComputerSystem";
+ ClassName = "OMC_ComputerSystem";
Namespaces = {"root/cimv2"};
ProviderType = {2,5}; // Instance, Method
};
@@ -29,8 +29,8 @@
instance of PG_ProviderCapabilities
{
CapabilityID = "OMC_HostNameSettingData";
- ProviderModuleName = "/usr/lib/pycim/OMC_UnitaryComputerSystem.py";
- ProviderName = "OMC_UnitaryComputerSystem";
+ ProviderModuleName = "/usr/lib/pycim/OMC_ComputerSystem.py";
+ ProviderName = "OMC_ComputerSystem";
ClassName = "OMC_HostNameSettingData";
Namespaces = {"root/cimv2"};
ProviderType = {2}; // Instance
@@ -39,8 +39,8 @@
instance of PG_ProviderCapabilities
{
CapabilityID = "OMC_ComputerSystemHostNameSettingData";
- ProviderModuleName = "/usr/lib/pycim/OMC_UnitaryComputerSystem.py";
- ProviderName = "OMC_UnitaryComputerSystem";
+ ProviderModuleName = "/usr/lib/pycim/OMC_ComputerSystem.py";
+ ProviderName = "OMC_ComputerSystem";
ClassName = "OMC_ComputerSystemHostNameSettingData";
Namespaces = {"root/cimv2"};
ProviderType = {2,3}; // Instance, Associator
Modified: pybase/trunk/OMC_ComputerSystem.mof
===================================================================
--- pybase/trunk/OMC_ComputerSystem.mof 2008-09-15 21:30:47 UTC (rev 975)
+++ pybase/trunk/OMC_ComputerSystem.mof 2008-09-15 21:31:55 UTC (rev 976)
@@ -2,8 +2,8 @@
//////////////////////////////////////////////////////////////////////////////
-[ Description("OMC Unitary Computer System"), Version("0.0.1") ]
-class OMC_UnitaryComputerSystem : CIM_UnitaryComputerSystem
+[ Description("OMC Computer System"), Version("0.0.1") ]
+class OMC_ComputerSystem : CIM_ComputerSystem
{
};
Modified: pybase/trunk/OMC_ComputerSystem.py
===================================================================
--- pybase/trunk/OMC_InitdService.mof 2008-09-15 21:30:47 UTC (rev 975)
+++ pybase/trunk/OMC_InitdService.mof 2008-09-15 21:31:55 UTC (rev 976)
@@ -150,7 +150,7 @@
{
[ Override("Antecedent"), Min(1), Max(1),
Description("The hosting system") ]
- OMC_UnitaryComputerSystem REF Antecedent;
+ OMC_ComputerSystem REF Antecedent;
[ Override("Dependent"), Weak, Min(0),
Description("The hosted init.d service") ]
@@ -165,7 +165,7 @@
{
[ Override("Antecedent"), Min(1), Max(1),
Description("The hosting system") ]
- OMC_UnitaryComputerSystem REF Antecedent;
+ OMC_ComputerSystem REF Antecedent;
[ Override("Dependent"), Weak, Min(0),
Description("The hosted runlevel") ]
Modified: pybase/trunk/OMC_InitdService.py
===================================================================
--- pybase/trunk/OMC_InitdService.py 2008-09-15 21:30:47 UTC (rev 975)
+++ pybase/trunk/OMC_InitdService.py 2008-09-15 21:31:55 UTC (rev 976)
@@ -186,7 +186,7 @@
% self.__class__.__name__)
model['SystemName'] = getfqdn()
- model['SystemCreationClassName'] = 'OMC_UnitaryComputerSystem'
+ model['SystemCreationClassName'] = 'OMC_ComputerSystem'
model['CreationClassName'] = 'OMC_InitdService'
for file in os.listdir('/etc/init.d'):
fullpath = '/etc/init.d/'+file
Modified: pybase/trunk/OMC_LogicalFile.py
===================================================================
--- pybase/trunk/OMC_LogicalFile.py 2008-09-15 21:30:47 UTC (rev 975)
+++ pybase/trunk/OMC_LogicalFile.py 2008-09-15 21:31:55 UTC (rev 976)
@@ -128,7 +128,7 @@
else:
map['Name'] = fname
map['CreationClassName'] = ccname
- map['CSCreationClassName'] = 'CIM_UnitaryComputerSystem'
+ map['CSCreationClassName'] = 'CIM_ComputerSystem'
map['CSName'] = getfqdn()
map['FSCreationClassName'] = 'CIM_FileSystem'
try:
Modified: pybase/trunk/OMC_OperatingSystem.mof
===================================================================
--- pybase/trunk/OMC_OperatingSystem.mof 2008-09-15 21:30:47 UTC (rev 975)
+++ pybase/trunk/OMC_OperatingSystem.mof 2008-09-15 21:31:55 UTC (rev 976)
@@ -44,7 +44,7 @@
[Override ( "Dependent" ), Max ( 1 ), Description (
"The ComputerSystem.")]
- OMC_UnitaryComputerSystem REF Dependent;
+ OMC_ComputerSystem REF Dependent;
};
// ===================================================================
@@ -63,7 +63,7 @@
[Aggregate, Override ( "GroupComponent" ), Min ( 1 ), Max ( 1 ),
Description (
"The ComputerSystem.")]
- OMC_UnitaryComputerSystem REF GroupComponent;
+ OMC_ComputerSystem REF GroupComponent;
[Override ( "PartComponent" ), Weak, Description (
"The OperatingSystem installed on the ComputerSystem.")]
Modified: pybase/trunk/OMC_OperatingSystem.py
===================================================================
--- pybase/trunk/OMC_OperatingSystem.py 2008-09-15 21:30:47 UTC (rev 975)
+++ pybase/trunk/OMC_OperatingSystem.py 2008-09-15 21:31:55 UTC (rev 976)
@@ -55,7 +55,7 @@
def get_os_path(ns):
return pywbem.CIMInstanceName(classname='OMC_OperatingSystem',
namespace=ns,
- keybindings={'CSCreationClassName': 'OMC_UnitaryComputerSystem',
+ keybindings={'CSCreationClassName': 'OMC_ComputerSystem',
'CreationClassName': 'OMC_OperatingSystem',
'Name': 'Linux',
'CSName': getfqdn()})
@@ -156,7 +156,7 @@
% self.__class__.__name__)
# Key properties
- model['CSCreationClassName'] = 'OMC_UnitaryComputerSystem'
+ model['CSCreationClassName'] = 'OMC_ComputerSystem'
model['CreationClassName'] = 'OMC_OperatingSystem'
model['Name'] = 'Linux'
model['CSName'] = getfqdn()
@@ -456,13 +456,13 @@
os = pywbem.CIMInstanceName('OMC_OperatingSystem',
namespace=model.path.namespace,
- keybindings={'CSCreationClassName':'OMC_UnitaryComputerSystem',
+ keybindings={'CSCreationClassName':'OMC_ComputerSystem',
'CreationClassName':'OMC_OperatingSystem',
'Name':'Linux',
'CSName':getfqdn()})
- cs = pywbem.CIMInstanceName('OMC_UnitaryComputerSystem',
+ cs = pywbem.CIMInstanceName('OMC_ComputerSystem',
namespace=model.path.namespace,
- keybindings={'CreationClassName':'OMC_UnitaryComputerSystem',
+ keybindings={'CreationClassName':'OMC_ComputerSystem',
'Name':getfqdn()})
if model.classname.lower() == 'omc_installedos':
@@ -499,9 +499,9 @@
cs = 'Dependent'
os = 'Antecedent'
model[cs] = pywbem.CIMInstanceName(
- classname='OMC_UnitaryComputerSystem',
+ classname='OMC_ComputerSystem',
namespace=object_name.namespace,
- keybindings={'CreationClassName':'OMC_UnitaryComputerSystem',
+ keybindings={'CreationClassName':'OMC_ComputerSystem',
'Name':getfqdn()})
model[os] = get_os_path(object_name.namespace)
yield model
Modified: pybase/trunk/OMC_SyslogNG.py
===================================================================
--- pybase/trunk/OMC_SyslogNG.py 2008-09-15 21:30:47 UTC (rev 975)
+++ pybase/trunk/OMC_SyslogNG.py 2008-09-15 21:31:55 UTC (rev 976)
@@ -781,8 +781,8 @@
% self.__class__.__name__)
for log in _get_syslog_list():
- model['Dependent'] = pywbem.CIMInstanceName('OMC_UnitaryComputerSystem',
- keybindings={'CreationClassName':'OMC_UnitaryComputerSystem',
+ model['Dependent'] = pywbem.CIMInstanceName('OMC_ComputerSystem',
+ keybindings={'CreationClassName':'OMC_ComputerSystem',
'Name':getfqdn()},
namespace=model.path.namespace)
model['Antecedent'] = pywbem.CIMInstanceName('OMC_SyslogNGRecordLog',
@@ -824,7 +824,7 @@
% self.__class__.__name__)
ch = env.get_cimom_handle()
if (not role or role.lower() == 'dependent') and \
- object_name.classname.lower() == 'omc_unitarycomputersystem':
+ object_name.classname.lower() == 'omc_computersystem':
model['Dependent'] = object_name
for log in _get_syslog_list():
model['Antecedent'] = pywbem.CIMInstanceName('OMC_SyslogNGRecordLog',
@@ -835,8 +835,8 @@
if (not role or role.lower() == 'antecedent') and \
object_name.classname.lower() == 'omc_syslogngrecordlog':
model['Antecedent'] = object_name
- model['Dependent'] = pywbem.CIMInstanceName('OMC_UnitaryComputerSystem',
- keybindings={'CreationClassName':'OMC_UnitaryComputerSystem',
+ model['Dependent'] = pywbem.CIMInstanceName('OMC_ComputerSystem',
+ keybindings={'CreationClassName':'OMC_ComputerSystem',
'Name':getfqdn()},
namespace=object_name.namespace)
yield model
Modified: pybase/trunk/OMC_TimeService.mof
===================================================================
--- pybase/trunk/OMC_TimeService.mof 2008-09-15 21:30:47 UTC (rev 975)
+++ pybase/trunk/OMC_TimeService.mof 2008-09-15 21:31:55 UTC (rev 976)
@@ -163,7 +163,7 @@
{
[ Override("Antecedent"), Min(1), Max(1),
Description("The hosting computer system") ]
- OMC_UnitaryComputerSystem REF Antecedent;
+ OMC_ComputerSystem REF Antecedent;
[ Override("Dependent"), Weak,
Description("The hosted system time service") ]
Modified: pybase/trunk/OMC_TimeService.py
===================================================================
--- pybase/trunk/OMC_TimeService.py 2008-09-15 21:30:47 UTC (rev 975)
+++ pybase/trunk/OMC_TimeService.py 2008-09-15 21:31:55 UTC (rev 976)
@@ -100,7 +100,7 @@
def fill_cim_obj(self, model, keys_only=False):
global ntp_inst_date
model['SystemName'] = _fqdn
- model['SystemCreationClassName'] = 'OMC_UnitaryComputerSystem'
+ model['SystemCreationClassName'] = 'OMC_ComputerSystem'
model['CreationClassName'] = 'OMC_RemoteTimeServicePort'
model['Name'] = self.server_name
if keys_only:
@@ -328,7 +328,7 @@
if 'CreationClassName' not in model \
or 'Name' not in model:
return False
- if model['CreationClassName'].lower() != 'omc_unitarycomputersystem':
+ if model['CreationClassName'].lower() != 'omc_computersystem':
return False
return model['Name'].lower() == _fqdn.lower()
@@ -337,7 +337,7 @@
for nm in ['SystemCreationClassName', 'SystemName', 'CreationClassName', 'Name']:
if nm not in model:
return False
- if model['SystemCreationClassName'].lower() != 'omc_unitarycomputersystem':
+ if model['SystemCreationClassName'].lower() != 'omc_computersystem':
return False
if model['SystemName'].lower() != _fqdn.lower():
return False
@@ -347,7 +347,7 @@
###############################################################################
def _fill_service_instance(model, keys_only):
- model['SystemCreationClassName'] = 'OMC_UnitaryComputerSystem'
+ model['SystemCreationClassName'] = 'OMC_ComputerSystem'
model['SystemName'] = _fqdn
model['CreationClassName'] = 'OMC_SystemTimeService'
model['Name'] = 'timeservice'
@@ -512,9 +512,9 @@
logger.log_debug('Entering %s.enum_instances()' \
% self.__class__.__name__)
model['Antecedent'] = pywbem.CIMInstanceName(
- classname='OMC_UnitaryComputerSystem',
+ classname='OMC_ComputerSystem',
namespace=model.path.namespace,
- keybindings={'CreationClassName':'OMC_UnitaryComputerSystem',
+ keybindings={'CreationClassName':'OMC_ComputerSystem',
'Name':_fqdn})
ref = pywbem.CIMInstanceName(classname='OMC_SystemTimeService',
namespace=model.path.namespace)
@@ -545,18 +545,18 @@
return
if result_class_name:
if not pywbem.is_subclass(env.get_cimom_handle(),
- object_name.namespace, sub='omc_unitarycomputersystem',
+ object_name.namespace, sub='omc_computersystem',
super=result_class_name):
return
model['Dependent'] = object_name
model['Antecedent'] = pywbem.CIMInstanceName(
- classname='OMC_UnitaryComputerSystem',
+ classname='OMC_ComputerSystem',
namespace=object_name.namespace,
- keybindings={'CreationClassName':'OMC_UnitaryComputerSystem',
+ keybindings={'CreationClassName':'OMC_ComputerSystem',
'Name':_fqdn})
yield model
- elif object_name.classname.lower() == 'omc_unitarycomputersystem':
+ elif object_name.classname.lower() == 'omc_computersystem':
if not _is_cs_ref(object_name):
return
if role and role.lower() != 'antecedent':
@@ -1058,9 +1058,9 @@
logger.log_debug('Entering %s.enum_instances()' \
% self.__class__.__name__)
model['userofservice'] = pywbem.CIMInstanceName(
- classname='OMC_UnitaryComputerSystem',
+ classname='OMC_ComputerSystem',
namespace=model.path.namespace,
- keybindings={'CreationClassName':'OMC_UnitaryComputerSystem',
+ keybindings={'CreationClassName':'OMC_ComputerSystem',
'Name':_fqdn})
ref = pywbem.CIMInstanceName(classname='OMC_SystemTimeService',
namespace=model.path.namespace)
@@ -1089,20 +1089,20 @@
return
if result_class_name:
if not pywbem.is_subclass(ch, object_name.namespace,
- sub='omc_unitarycomputersystem',
+ sub='omc_computersystem',
super=result_class_name):
return
if not _is_service_ref(object_name):
return
model['serviceprovided'] = object_name
model['userofservice'] = pywbem.CIMInstanceName(
- classname='OMC_UnitaryComputerSystem',
+ classname='OMC_ComputerSystem',
namespace=object_name.namespace,
- keybindings={'CreationClassName':'OMC_UnitaryComputerSystem',
+ keybindings={'CreationClassName':'OMC_ComputerSystem',
'Name':_fqdn})
yield model
- elif object_name.classname.lower() == 'omc_unitarycomputersystem':
+ elif object_name.classname.lower() == 'omc_computersystem':
if role and role.lower() != 'userofservice':
return
if result_role and result_role.lower() != 'serviceprovided':
Modified: pybase/trunk/OMC_UnixProcess.py
===================================================================
--- pybase/trunk/OMC_UnixProcess.py 2008-09-15 21:30:47 UTC (rev 975)
+++ pybase/trunk/OMC_UnixProcess.py 2008-09-15 21:31:55 UTC (rev 976)
@@ -212,7 +212,7 @@
keybindings={'OSCreationClassName':'OMC_OperatingSystem',
'CreationClassName':'OMC_UnixProcess',
'Handle':str(self.pid),
- 'CSCreationClassName':'OMC_UnitaryComputerSystem',
+ 'CSCreationClassName':'OMC_ComputerSystem',
'OSName':'Linux',
'CSName':getfqdn()})
@@ -461,7 +461,7 @@
ux(OSCreationClassName= 'OMC_OperatingSystem')
ux(CreationClassName= 'OMC_UnixProcess')
ux(Handle= str(lp.pid))
- ux(CSCreationClassName= 'OMC_UnitaryComputerSystem')
+ ux(CSCreationClassName= 'OMC_ComputerSystem')
ux(OSName= 'Linux')
ux(CSName= getfqdn())
if keys_only:
Modified: pybase/trunk/setup.py
===================================================================
--- pybase/trunk/setup.py 2008-09-15 21:30:47 UTC (rev 975)
+++ pybase/trunk/setup.py 2008-09-15 21:31:55 UTC (rev 976)
@@ -22,7 +22,7 @@
py_modules=['OMC_InitdService',
'OMC_LogicalFile',
'OMC_OperatingSystem',
- 'OMC_UnitaryComputerSystem',
+ 'OMC_ComputerSystem',
'OMC_UnixProcess',
'OMC_SyslogNG',
'OMC_TimeService',]
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
--- pybase/trunk/OMC_ComputerSystem.py 2008-09-15 21:30:47 UTC (rev 975)
+++ pybase/trunk/OMC_ComputerSystem.py 2008-09-15 21:31:55 UTC (rev 976)
@@ -28,9 +28,9 @@
# POSSIBILITY OF SUCH DAMAGE.
#
#*****************************************************************************/
-"""Python Provider for OMC_UnitaryComputerSystem
+"""Python Provider for OMC_ComputerSystem
-Instruments the CIM class OMC_UnitaryComputerSystem
+Instruments the CIM class OMC_ComputerSystem
"""
@@ -38,10 +38,10 @@
from pywbem import CIMProvider
from socket import getfqdn
-class OMC_UnitaryComputerSystemProvider(CIMProvider):
- """Instrument the CIM class OMC_UnitaryComputerSystem
+class OMC_ComputerSystemProvider(CIMProvider):
+ """Instrument the CIM class OMC_ComputerSystem
- OMC Unitary Computer System
+ OMC Computer System
"""
@@ -132,7 +132,7 @@
% self.__class__.__name__)
# Key properties
- model['CreationClassName'] = 'OMC_UnitaryComputerSystem'
+ model['CreationClassName'] = 'OMC_ComputerSystem'
model['Name'] = getfqdn()
if keys_only:
yield model
@@ -212,7 +212,7 @@
def cim_method_requeststatechange(self, env, object_name, method,
param_requestedstate,
param_timeoutperiod):
- """Implements OMC_UnitaryComputerSystem.RequestStateChange()
+ """Implements OMC_ComputerSystem.RequestStateChange()
Requests that the state of the element be changed to the value
specified in the RequestedState parameter. When the requested
@@ -276,7 +276,7 @@
def cim_method_setpowerstate(self, env, object_name, method,
param_powerstate,
param_time):
- """Implements OMC_UnitaryComputerSystem.SetPowerState()
+ """Implements OMC_ComputerSystem.SetPowerState()
Sets the power state of the computer. The use of this method has
been deprecated. Instead, use the SetPowerState method in the
@@ -534,13 +534,13 @@
# DMTF_Reserved = ..
# Vendor_Reserved = 32768..65535
## end of class OMC_UnitaryComputerSystemProvider
def get_providers(env): # register provider
- omc_unitarycomputersystem_prov = OMC_UnitaryComputerSystemProvider()
- return {'OMC_UnitaryComputerSystem': omc_unitarycomputersystem_prov}
+ omc_computersystem_prov = OMC_ComputerSystemProvider()
+ return {'OMC_ComputerSystem': omc_computersystem_prov}
Modified: pybase/trunk/OMC_InitdService.mof
===================================================================
@@ -534,13 +534,13 @@
# DMTF_Reserved = ..
# Vendor_Reserved = 32768..65535
-## end of class OMC_UnitaryComputerSystemProvider
+## end of class OMC_ComputerSystemProvider
def get_providers(env): # register provider